# -*- coding: utf-8 -*-
import os
import sys

__author__ = """Vu Anh"""
__email__ = 'anhv.ict91@gmail.com'

# Check python version
try:
    version_info = sys.version_info
    if version_info < (3, 6, 0):
        raise RuntimeError("underthesea requires Python 3.6 or later")
except Exception:
    pass

###########################################################
# METADATA
###########################################################

# Version
try:
    version_file = os.path.join(os.path.dirname(__file__), 'VERSION')
    with open(version_file, 'r') as infile:
        __version__ = infile.read().strip()
except NameError:
    __version__ = 'unknown (running code interactively?)'
except IOError as ex:
    __version__ = "unknown (%s)" % ex

###########################################################
# TOP-LEVEL MODULES
###########################################################
from underthesea.sent_tokenize import sent_tokenize
from underthesea.word_tokenize import word_tokenize
from underthesea.pos_tag import pos_tag
from underthesea.chunking import chunk
from underthesea.ner import ner

try:
    from underthesea.classification import classify
except Exception:
    pass
try:
    from underthesea.sentiment import sentiment
except Exception:
    pass

__all__ = [
    'sent_tokenize',
    'word_tokenize', 'pos_tag', 'chunk', 'ner',
    'classify', 'sentiment'
]



# -*- coding: utf-8 -*-

from unittest import TestCase

from underthesea.dictionary import Dictionary
from underthesea.feature_engineering.text import Text


class TestDictionary(TestCase):
    def test_1(self):
        dictionary = Dictionary.Instance()
        senses = dictionary.lookup(Text("đi"))
        self.assertEqual(22, len(senses))
        sense = senses[0]
        self.assertEqual("V", sense["pos"])
        self.assertGreater(len(sense["definition"]), 0)

    def test_2(self):
        dictionary = Dictionary.Instance()
        word = dictionary.lookup(Text("không có từ này"))
        self.assertEqual(None, word)



# -*- coding: utf-8 -*-


def sentiment(X, domain='general'):
    """
    Sentiment Analysis

    Parameters
    ==========

    X: {unicode, str}
        raw sentence
    domain: {'bank'}
        domain of text
            * bank: bank domain
    Returns
    =======
    Text: Text of input sentence
    Labels: Sentiment of sentence

    Examples
    --------

    >>> # -*- coding: utf-8 -*-
    >>> from underthesea import sentiment
    >>> sentence = "Chuyen tiền k nhận Dc tiên"
    >>> sentiment(sentence, domain='bank')

    [MONEY_TRANSFER#negative (1.0)]
    """
    if X == "":
        return None
    if domain == 'general':
        from underthesea.sentiment.general import sentiment
        return sentiment(X)
    if domain == 'bank':
        from underthesea.sentiment.bank import sentiment
        return sentiment(X)



from pathlib import Path
from typing import List, Union


class Corpus:
    pass


class Label:
    def __init__(self, value: str, score: float = 1.0):
        self.value = value
        self.score = score

    @property
    def value(self):
        return self._value

    @property
    def score(self):
        return self._score

    @value.setter
    def value(self, value):
        self._value = value

    @score.setter
    def score(self, score):
        if 0.0 <= score <= 1.0:
            self._score = score
        else:
            self._score = 1.0

    def __str__(self):
        return "{} ({})".format(self._value, self._score)

    def __repr__(self):
        return "{} ({})".format(self._value, self._score)


class Sentence:
    def __init__(
        self,
        text: str = None,
        labels: Union[List[Label], List[str]] = None
    ):
        self.text = text
        self.labels = labels

    def __str__(self) -> str:
        return f'Sentence: "{self.text}" - Labels: {self.labels}'

    def __repr__(self) -> str:
        return f'Sentence: "{self.text}" - Labels: {self.labels}'

    def to_text_classification_format(self) -> str:
        labels_text = " ".join([f"__label__{label.value}" for label in self.labels])
        output = f"{labels_text} {self.text}"
        return output

    def add_labels(self, labels: Union[List[Label], List[str]]):
        for label in labels:
            if type(label) == str:
                label = Label(label)
            if not self.labels:
                self.labels = []
            self.labels.append(label)


class PlaintextCorpus(Corpus):
    def __init__(self, sentences):
        self.sentences = sentences


class CategorizedCorpus(Corpus):
    def __init__(
        self,
        train: List[Sentence],
        dev: List[Sentence],
        test: List[Sentence]
    ):
        self._train: List[Sentence] = train
        self._dev: List[Sentence] = dev
        self._test: List[Sentence] = test

    @property
    def train(self) -> List[Sentence]:
        return self._train

    @property
    def dev(self) -> List[Sentence]:
        return self._dev

    @property
    def test(self) -> List[Sentence]:
        return self._test

    def __str__(self) -> str:
        return "CategorizedCorpus: %d train + %d dev + %d test sentences" % (
            len(self.train),
            len(self.dev),
            len(self.test),
        )

    def save(self, data_folder: str):
        self.save_sentences(self._train, f"{data_folder}/train.txt")
        self.save_sentences(self._dev, f"{data_folder}/dev.txt")
        self.save_sentences(self._test, f"{data_folder}/test.txt")

    def save_sentences(self, sentences: List[Sentence], path_to_file: Union[Path, str]):
        with open(path_to_file, "w") as f:
            for sentence in sentences:
                f.write(sentence.to_text_classification_format() + "\n")


class TaggedCorpus(Corpus):
    pass



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea import word_tokenize
import signal


def timeout_handler(signum, frame):
    raise Exception("Timeout Exception")


class TestWordTokenize(TestCase):
    def test_simple_cases(self):
        sentence = u""
        actual = word_tokenize(sentence)
        expected = []
        self.assertEqual(actual, expected)

        actual = word_tokenize(sentence, format="text")
        expected = u""
        self.assertEqual(actual, expected)

    def test_special_cases_2(self):
        sentence = u"="
        actual = word_tokenize(sentence)
        expected = ["="]
        self.assertEqual(actual, expected)

    def test_special_cases_3(self):
        sentence = u"=))"
        actual = word_tokenize(sentence)
        expected = ["=))"]
        self.assertEqual(actual, expected)

    def test_decomposed_from(self):
        text = u"yếu"
        acutal = word_tokenize(text)
        expected = [u'yếu']
        self.assertEqual(acutal, expected)

    def test_word_tokenize(self):
        text = u"""Tổng thống Nga coi việc Mỹ không kích căn cứ quân sự của Syria là "sự gây hấn nhằm vào một quốc gia có chủ quyền", gây tổn hại đến quan hệ Moscow-Washington."""
        word_tokenize(text)

    def test_word_tokenize_2(self):
        """ Case with special character tab
        """
        signal.signal(signal.SIGALRM, timeout_handler)
        signal.alarm(1)
        try:
            text = u"""000000000000_753889211466429	"""
            word_tokenize(text)
        except Exception as e:
            raise (e)

    def test_url_1(self):
        text = u"https://www.facebook.com/photo.php?fbid=1627680357512432&set=a.1406713109609159.1073741826.100008114498358&type=1 mình muốn chia sẻ bài viết của một bác nói về thực trạng của bộ giáo dục bây giờ! mọi người vào đọc và chia sẻ để Phạm Vũ Luận BIẾT!"
        actual = word_tokenize(text, format='text')
        expected = u"https://www.facebook.com/photo.php?fbid=1627680357512432&set=a.1406713109609159.1073741826.100008114498358&type=1 mình muốn chia_sẻ bài viết của một bác nói về thực_trạng của bộ giáo_dục bây_giờ ! mọi người vào đọc và chia_sẻ để Phạm_Vũ_Luận BIẾT !"
        self.assertEqual(actual, expected)



# -*- coding: utf-8 -*-
from click.testing import CliRunner
from unittest import TestCase, skip
from underthesea.cli import download_data, list_data, remove_data


class TestCliData(TestCase):
    @skip
    def test_download_data_raw_file(self):
        runner = CliRunner()
        # data_name = "VNTQ_BIG"
        # data_name = "VNTQ_SMALL"
        data_name = "VNESES"
        result = runner.invoke(download_data, [data_name])
        print(result.output)

    @skip
    def test_download_data_zip_file(self):
        runner = CliRunner()
        data_name = "UTS2017-BANK"
        # url = ""
        result = runner.invoke(download_data, [data_name])
        print(result.output)

    @skip
    def test_list_data(self):
        runner = CliRunner()
        result = runner.invoke(list_data)
        print(result.output)

    @skip
    def test_list_data_2(self):
        runner = CliRunner()
        result = runner.invoke(list_data, ['--all'])
        print(result.output)

    @skip
    def test_remove_data(self):
        runner = CliRunner()
        result = runner.invoke(remove_data, ['VNESES'])
        print(result.output)



import os
import sys
from os.path import dirname
import logging
from underthesea.data import Sentence
from underthesea.model_fetcher import UTSModel, ModelFetcher
from underthesea.models_lf.text_classifier import TextClassifier

FORMAT = '%(message)s'
logging.basicConfig(format=FORMAT)
logger = logging.getLogger('underthesea')

sys.path.insert(0, dirname(dirname(__file__)))

model_path = ModelFetcher.get_model_path(UTSModel.tc_general)

classifier = None


def classify(X):
    global classifier

    if not classifier:
        if os.path.exists(model_path):
            classifier = TextClassifier.load(model_path)
        else:
            logger.error(
                f"Could not load model at {model_path}.\n"
                f"Download model with \"underthesea download {UTSModel.tc_general.value}\".")
            sys.exit(1)

    sentence = Sentence(X)
    classifier.predict(sentence)
    labels = sentence.labels
    return labels



import os
import shutil
import zipfile
from enum import Enum
from pathlib import Path

from tabulate import tabulate

from underthesea.file_utils import cached_path, CACHE_ROOT
from underthesea.models import REPO

MISS_URL_ERROR = "Caution:\n  With closed license model, you must provide URL to download"


class UTSModel(Enum):
    tc_general = "TC_GENERAL"
    tc_bank = "TC_BANK"

    sa_general = "SA_GENERAL"
    sa_bank = "SA_BANK"


class ModelFetcher:

    @staticmethod
    def download(model_name):
        if model_name not in REPO:
            print(f"No matching distribution found for '{model_name}'")
            return

        model_path = REPO[model_name]["model_path"]
        cache_dir = REPO[model_name]["cache_dir"]
        model_path = Path(CACHE_ROOT) / cache_dir / model_path
        if Path(model_path).exists():
            print(f"Model is already existed: '{model_name}' in {model_path}")
            return

        if model_name == "TC_GENERAL":
            url = "https://www.dropbox.com/s/866offu8wglrcej/tc_svm_vntc_20190607.zip?dl=1"
            cached_path(url, cache_dir=cache_dir)
            model_path = Path(CACHE_ROOT) / cache_dir / "tc_svm_vntc_20190607.zip?dl=1"
            cache_folder = Path(CACHE_ROOT) / cache_dir
            zip = zipfile.ZipFile(model_path)
            zip.extractall(cache_folder)
            os.rename(
                Path(CACHE_ROOT) / cache_dir / "tc_svm_vntc_20190607",
                Path(CACHE_ROOT) / cache_dir / "TC_GENERAL",
            )
            os.remove(model_path)

        if model_name == "TC_BANK":
            url = "https://www.dropbox.com/s/prrjlypbrr6ze6p/tc_svm_uts2017_bank_20190607.zip?dl=1"
            cached_path(url, cache_dir=cache_dir)
            model_path = Path(CACHE_ROOT) / cache_dir / "tc_svm_uts2017_bank_20190607.zip?dl=1"
            cache_folder = Path(CACHE_ROOT) / cache_dir
            zip = zipfile.ZipFile(model_path)
            zip.extractall(cache_folder)
            os.rename(
                Path(CACHE_ROOT) / cache_dir / "tc_svm_uts2017_bank_20190607",
                Path(CACHE_ROOT) / cache_dir / "TC_BANK",
            )
            os.remove(model_path)

        if model_name == "SA_GENERAL":
            url = "https://www.dropbox.com/s/xfj1ity3egabv77/sa_svm_aivivn2019_20190615.zip?dl=1"
            cached_path(url, cache_dir=cache_dir)
            model_path = Path(CACHE_ROOT) / cache_dir / "sa_svm_aivivn2019_20190615.zip?dl=1"
            cache_folder = Path(CACHE_ROOT) / cache_dir
            zip = zipfile.ZipFile(model_path)
            zip.extractall(cache_folder)
            os.rename(
                Path(CACHE_ROOT) / cache_dir / "sa_svm_aivivn2019_20190615",
                Path(CACHE_ROOT) / cache_dir / "SA_GENERAL",
            )
            os.remove(model_path)

        if model_name == "SA_BANK":
            url = "https://www.dropbox.com/s/yo6sf6ofpdb3hlh/sa_svm_uts2017_bank_20190611.zip?dl=1"
            cached_path(url, cache_dir=cache_dir)
            model_path = Path(CACHE_ROOT) / cache_dir / "sa_svm_uts2017_bank_20190611.zip?dl=1"
            cache_folder = Path(CACHE_ROOT) / cache_dir
            zip = zipfile.ZipFile(model_path)
            zip.extractall(cache_folder)
            os.rename(
                Path(CACHE_ROOT) / cache_dir / "sa_svm_uts2017_bank_20190611",
                Path(CACHE_ROOT) / cache_dir / "SA_BANK",
            )
            os.remove(model_path)

    @staticmethod
    def list(all):
        models = []
        for key in REPO:
            name = key
            type = REPO[key]["type"]
            license = REPO[key]["license"]
            year = REPO[key]["year"]
            directory = Path(REPO[key]["cache_dir"]) / REPO[key]["model_path"]
            if not all:
                if license == "Close":
                    continue
            if license == "Close":
                license = "Close*"
            models.append([name, type, license, year, directory])

        print(tabulate(models,
                       headers=["Name", "Type", "License", "Year", "Directory"],
                       tablefmt='orgtbl'))

        if all:
            print(f"\n{MISS_URL_ERROR}")

    @staticmethod
    def remove(model_name):
        if model_name not in REPO:
            print(f"No matching distribution found for '{model_name}'")
            return
        model = REPO[model_name]
        cache_dir = Path(CACHE_ROOT) / model["cache_dir"] / model["model_path"]
        if cache_dir.is_dir():
            shutil.rmtree(cache_dir)
        print(f"Model {model_name} is removed.")

    @staticmethod
    def get_model_path(model):
        if model == UTSModel.tc_bank:
            return Path(CACHE_ROOT) / "models" / "TC_BANK"

        if model == UTSModel.tc_general:
            return Path(CACHE_ROOT) / "models" / "TC_GENERAL"

        if model == UTSModel.sa_general:
            return Path(CACHE_ROOT) / "models" / "SA_GENERAL"

        if model == UTSModel.sa_bank:
            return Path(CACHE_ROOT) / "models" / "SA_BANK"



# -*- coding: utf-8 -*-
from .regex_tokenize import tokenize
from .model import CRFModel


def word_tokenize(sentence, format=None):
    """
    Vietnamese word segmentation

    Parameters
    ==========

    sentence: {unicode, str}
        raw sentence

    Returns
    =======
    tokens: list of text
        tagged sentence

    Examples
    --------

    >>> # -*- coding: utf-8 -*-
    >>> from underthesea import word_tokenize
    >>> sentence = "Bác sĩ bây giờ có thể thản nhiên báo tin bệnh nhân bị ung thư"

    >>> word_tokenize(sentence)
    ['Bác sĩ', 'bây giờ', 'có thể', 'thản nhiên', 'báo tin', 'bệnh nhân', 'bị', 'ung thư']

    >>> word_tokenize(sentence, format="text")
    'Bác_sĩ bây_giờ có_thể thản_nhiên báo_tin bệnh_nhân bị ung_thư'
    """
    tokens = tokenize(sentence)
    crf_model = CRFModel.instance()
    output = crf_model.predict(tokens, format)
    tokens = [token[0] for token in output]
    tags = [token[1] for token in output]
    output = []
    for tag, token in zip(tags, tokens):
        if tag == "I-W":
            output[-1] = output[-1] + u" " + token
        else:
            output.append(token)
    if format == "text":
        output = u" ".join([item.replace(" ", "_") for item in output])
    return output



from os import mkdir
from os.path import join
import pandas as pd
import io

import shutil
from languageflow.util.file_io import read, write


class TaggedCorpus:
    def __init__(self, sentences=[]):
        self.sentences = sentences

    def save(self, filepath):
        sentences = self.sentences
        content = "\n\n".join(
            ["\n".join(["\t".join(t) for t in s]) for s in sentences])
        with io.open(filepath, "w", newline="\n", encoding="utf-8") as f:
            f.write(content)

    def _parse_sentence(self, text, skip_column=None):
        tokens = text.split("\n")
        if skip_column is None:
            tokens = [token.split("\t") for token in tokens if str(token).strip() != ""]
        else:
            tokens = [token.split("\t")[(skip_column + 1):] for token in tokens if str(token).strip() != ""]
        return tokens

    def load(self, filepath, skip_column=None):
        content = read(filepath).strip()
        sentences = content.split("\n\n")
        sentences = [self._parse_sentence(str(s).strip(), skip_column) for s in sentences if str(s).strip() != ""]
        self.sentences = sentences

    def _analyze_field(self, df, id, output_folder=".", n_head=10):
        id = str(id)
        m = df.shape[1]
        df.columns = [str(i) for i in range(m)]

        agg_dict = dict()
        agg_dict[id] = "size"
        for i in range(int(id)):
            agg_dict[str(i)] = lambda x: ", ".join(
                pd.value_counts(x).index[:n_head])
        name_dict = dict()
        name_dict[id] = "count"
        df_analyze = df.groupby(id).agg(agg_dict).rename(
            columns=name_dict).reset_index()
        filename = join(output_folder, "column-%s-analyze.xlsx" % id)

        log = u""
        log += u"Tags         : {}\n".format(df_analyze.shape[0])
        tags = df_analyze[id].to_dict().values()
        tags = sorted(tags)
        log += u"List tags    : {}\n".format(u", ".join(tags))
        df_analyze.to_excel(filename, index=False)
        return log

    def _analyze_first_token(self, df, id, output_folder="."):
        filename = join(output_folder, "column-%s-analyze.xlsx" % id)
        df_analyze = df[id].value_counts().reset_index(name="count")
        df_analyze = df_analyze.rename(columns={"index": "0"})
        df_analyze.to_excel(filename, index=False)
        log = u""
        log += u"Unique words : {}\n".format(df_analyze.shape[0])
        log += u"Top words    : {}\n".format(
            u", ".join(list(df_analyze["0"].to_dict().values())[:20]))
        return log

    def analyze(self, output_folder=".", auto_remove=False):
        """
        :type auto_remove: boolean
        :param boolean auto_remove: auto remove previous files in analyze folder
        """
        if auto_remove:
            try:
                shutil.rmtree(output_folder)
            except Exception:
                pass
        try:
            mkdir(output_folder)
        except Exception:
            pass
        tokens = [token for sublist in self.sentences for token in sublist]
        df = pd.DataFrame(tokens)
        log = u""
        log += u"Sentences    : {}\n".format(len(self.sentences))
        n = df.shape[1]
        log += self._analyze_first_token(df, 0, output_folder)
        for i in range(1, n):
            log += self._analyze_field(df, i, output_folder)
        print(log)
        stat_file = join(output_folder, "stats.txt")
        write(stat_file, log)



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea import pos_tag


class TestPostag(TestCase):
    def test_simple_cases(self):
        sentence = u""
        actual = pos_tag(sentence)
        expected = []
        self.assertEqual(actual, expected)

    def test_accuracy(self):
        output = pos_tag(u"Tổng Bí thư: Ai trót để tay nhúng chàm thì hãy sớm tự gột rửa")
        self.assertEqual(len(output), 13)



from unittest import TestCase
from underthesea.corpus import viet_dict_11K
import sys

if sys.version_info >= (3, 0):
    unicode = str


class Test_VietDict(TestCase):
    def test_viet_dict(self):
        words = viet_dict_11K.words
        self.assertEqual(11373, len(words))

    def test_unicode(self):
        word = viet_dict_11K.words[0]
        self.assertEqual(unicode, type(word))



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea.word_tokenize.regex_tokenize import tokenize


class TestTokenize(TestCase):
    def test_tokenize(self):
        text = u"""Tổng thống Nga coi việc Mỹ không kích căn cứ quân sự của Syria là "sự gây hấn nhằm vào một quốc gia có chủ quyền", gây tổn hại đến quan hệ Moscow-Washington."""
        actual = tokenize(text, format="text")
        expected = u'Tổng thống Nga coi việc Mỹ không kích căn cứ quân sự của Syria là " sự gây hấn nhằm vào một quốc gia có chủ quyền " , gây tổn hại đến quan hệ Moscow-Washington .'
        self.assertEqual(expected, actual)

    def test_tokenize_2(self):
        text = u"""Vào tháng 10 năm ngoái, nghi phạm này từng bị bắt khi ăn cắp 25 mỹ phẩm trị giá 24.000 yen (hơn 200 USD) tại một cửa hàng giảm giá ở tỉnh Hyogo. Cùng năm, 4 thành viên khác cũng bị bắt vì ăn cắp một số lượng lớn son dưỡng môi và mỹ phẩm tại các cửa hiệu ở Osaka. Sau khi bị truy tố, 3 người trong số này được hưởng án treo."""
        actual = tokenize(text, format="text")
        expected = u'Vào tháng 10 năm ngoái , nghi phạm này từng bị bắt khi ăn cắp 25 mỹ phẩm trị giá 24.000 yen ( hơn 200 USD ) tại một cửa hàng giảm giá ở tỉnh Hyogo . Cùng năm , 4 thành viên khác cũng bị bắt vì ăn cắp một số lượng lớn son dưỡng môi và mỹ phẩm tại các cửa hiệu ở Osaka . Sau khi bị truy tố , 3 người trong số này được hưởng án treo .'
        self.assertEqual(expected, actual)

    def test_tokenize_3(self):
        text = u"""Giá khuyến mãi: 140.000đ / kg  ==> giảm được 20%"""
        actual = tokenize(text, format="text")
        expected = u'Giá khuyến mãi : 140.000 đ / kg ==> giảm được 20 %'
        self.assertEqual(expected, actual)

    def test_tokenize_4(self):
        text = u"""Microsoft hôm nay đã công bố cấu hình chính thức của thế hệ Xbox tiếp theo, tên mã Scorpio, và tin tưởng đây là loại console có sức mạnh xử lý cao nhất hiện giờ, mạnh hơn cả PS4 Pro. Tại buổi demo sản phẩm, Xbox Scorpio có thể chơi game đua xe Forza độ phân giải 4K với tốc độ đạt tới 60 khung hình/giây. Đồng thời Xbox Scorpio cũng sẽ tương thích với các tựa game Xbox cũ và quan trọng hơn nữa đó là các tựa game đó sẽ có đồ họa đẹp hơn, FPS cao hơn, thời gian load nhanh hơn khi chạy trên Xbox Scorpio."""
        actual = tokenize(text, format="text")
        expected = u'Microsoft hôm nay đã công bố cấu hình chính thức của thế hệ Xbox tiếp theo , tên mã Scorpio , và tin tưởng đây là loại console có sức mạnh xử lý cao nhất hiện giờ , mạnh hơn cả PS4 Pro . Tại buổi demo sản phẩm , Xbox Scorpio có thể chơi game đua xe Forza độ phân giải 4K với tốc độ đạt tới 60 khung hình / giây . Đồng thời Xbox Scorpio cũng sẽ tương thích với các tựa game Xbox cũ và quan trọng hơn nữa đó là các tựa game đó sẽ có đồ họa đẹp hơn , FPS cao hơn , thời gian load nhanh hơn khi chạy trên Xbox Scorpio .'
        self.assertEqual(actual, expected)

    def test_tokenize_5(self):
        text = u"""Tuyên bố của Điện Kremlin cũng nhấn mạnh, vụ tấn công sẽ “hủy hoại nghiêm trọng quan hệ Nga-Mỹ” và tạo ra “trở ngại cực lớn” cho việc tạo lập một liên minh quốc tế chống Tổ chức Nhà nước Hồi giáo tự xưng (IS)."""
        actual = tokenize(text, format="text")
        expected = u'Tuyên bố của Điện Kremlin cũng nhấn mạnh , vụ tấn công sẽ “ hủy hoại nghiêm trọng quan hệ Nga-Mỹ ” và tạo ra “ trở ngại cực lớn ” cho việc tạo lập một liên minh quốc tế chống Tổ chức Nhà nước Hồi giáo tự xưng ( IS ) .'
        self.assertEqual(expected, actual)

    def test_tokenize_6(self):
        text = u"""Ngày 11 tháng 3 là ngày thứ 70 (71 trong năm nhuận) trong lịch Gregory. Còn 295 ngày trong năm."""
        actual = tokenize(text, format="text")
        expected = u'Ngày 11 tháng 3 là ngày thứ 70 ( 71 trong năm nhuận ) trong lịch Gregory . Còn 295 ngày trong năm .'
        self.assertEqual(expected, actual)

    def test_tokenize_7(self):
        text = u"""Kết quả xổ số điện toán Vietlott ngày 6/2/2017"""
        actual = tokenize(text, format="text")
        expected = u"Kết quả xổ số điện toán Vietlott ngày 6/2/2017"
        self.assertEqual(expected, actual)

    def test_tokenize_8(self):
        text = u"""Theo thông báo kết luận thanh tra của UBND tỉnh Thanh Hoá sáng nay 30/3, giai đoạn 2010-2015 Sở Xây dựng Thanh Hoá đã bổ nhiệm một số trưởng phòng, phó phòng chưa có trình độ Trung cấp lý luận chính trị, chưa qua lớp bồi dưỡng nghiệp vụ quản lý nhà nước, không đúng quy định của UBND tỉnh Thanh Hoá.
"""
        actual = tokenize(text, format="text")
        expected = u"Theo thông báo kết luận thanh tra của UBND tỉnh Thanh Hoá sáng nay 30/3 , giai đoạn 2010 - 2015 Sở Xây dựng Thanh Hoá đã bổ nhiệm một số trưởng phòng , phó phòng chưa có trình độ Trung cấp lý luận chính trị , chưa qua lớp bồi dưỡng nghiệp vụ quản lý nhà nước , không đúng quy định của UBND tỉnh Thanh Hoá ."
        self.assertEqual(expected, actual)

    def test_special(self):
        text = 'v.v...'
        actual = tokenize(text, format="text")
        expected = 'v.v...'
        self.assertEqual(expected, actual)

    def test_abbreviation_1(self):
        text = u"""UBND. HĐND. TP."""
        actual = tokenize(text, format="text")
        expected = u"UBND. HĐND. TP ."
        self.assertEqual(expected, actual)

    def test_abbreviation_2(self):
        text = 'Toàn cảnh lễ ký kết giữa công ty Tân Thạnh A và công ty Lotte E&C'
        actual = tokenize(text, format="text")
        expected = 'Toàn cảnh lễ ký kết giữa công ty Tân Thạnh A và công ty Lotte E&C'
        self.assertEqual(expected, actual)

    def test_abbreviation_3(self):
        text = 'L.ANH N.ẨN Chị T.T.M.'
        actual = tokenize(text, format="text")
        expected = 'L.ANH N.ẨN Chị T.T.M.'
        self.assertEqual(expected, actual)

    def test_abbreviation_4(self):
        text = 'một ở làng H\'Lũ H\'Mông'
        actual = tokenize(text, format="text")
        expected = 'một ở làng H\'Lũ H\'Mông'
        self.assertEqual(expected, actual)

    def test_url(self):
        urls = [
            "google.com",
            "https://www.facebook.com/photo.php?fbid=1627680357512432&set=a.1406713109609159.1073741826.100008114498358&type=1"
        ]
        for url in urls:
            actual = tokenize(url, format="text")
            expected = url
            self.assertEqual(expected, actual)

    def test_url_2(self):
        text = "việt đẹp mã.ftp://mp3.zing.vn vinh@zing.com.vn"
        actual = tokenize(text, format="text")
        expected = "việt đẹp mã . ftp://mp3.zing.vn vinh@zing.com.vn"
        self.assertEqual(expected, actual)

    def test_datetime_1(self):
        text = "29-10-2004 Ngày 2/2014 6/2 6/2/2014 6-2 6-2-99 6.2 7.3.2014 2010-2015 2004/09/15 08:41:40"
        actual = tokenize(text, format="text")
        expected = "29-10-2004 Ngày 2/2014 6/2 6/2/2014 6-2 6-2-99 6.2 7.3.2014 2010 - 2015 2004/09/15 08:41:40"
        self.assertEqual(expected, actual)

    def test_datetime_2(self):
        text = "vào tháng 5-2002 , 11-2003 và 8-3-2004"
        actual = tokenize(text, format="text")
        expected = "vào tháng 5-2002 , 11-2003 và 8-3-2004"
        self.assertEqual(expected, actual)

    def test_name(self):
        text = "Xe gắn máy số 53S5 - 3720"
        actual = tokenize(text, format="text")
        expected = "Xe gắn máy số 53S5 - 3720"
        self.assertEqual(expected, actual)

    def test_number(self):
        text = "tổng cộng 60.542.000 đồng 100,000,000"
        actual = tokenize(text, format="text")
        expected = "tổng cộng 60.542.000 đồng 100,000,000"
        self.assertEqual(expected, actual)

    def test_number_2(self):
        text = "1.600m-2.000m Nó chỉ có mặt ở vùng đất độ cao 1.600m-2.000m so với mặt biển."
        actual = tokenize(text, format="text")
        expected = "1.600 m - 2.000 m Nó chỉ có mặt ở vùng đất độ cao 1.600 m - 2.000 m so với mặt biển ."
        self.assertEqual(expected, actual)

    def test_emoji(self):
        text = 'Tầm giá quá rẻ để mua 1 cục bực tức để trên người :)) <3'
        actual = tokenize(text, format="text")
        expected = 'Tầm giá quá rẻ để mua 1 cục bực tức để trên người :)) <3'
        self.assertEqual(expected, actual)

    def test_word_hyphen(self):
        text = 'Tiêm kích F-16 Bỉ kích bom Su-34 Nga Tàu Apolo-2 Đoàn tàu SE-4 kiểm soát 49X-6666 Rolls-Royce'
        actual = tokenize(text, format="text")
        expected = 'Tiêm kích F-16 Bỉ kích bom Su-34 Nga Tàu Apolo-2 Đoàn tàu SE-4 kiểm soát 49X-6666 Rolls-Royce'
        self.assertEqual(expected, actual)

    def test_punct(self):
        text = '(baodautu.vn) Trao đổi với báo chí chiều 27/5, ông Lê Quốc Bình, TGĐ Công ty cổ phần đầu tư hạ tầng kỹ thuật TP. HCM (CII) chính thức thông tin: UBND TP vừa có quyết định cho phép CII được thu phí hoàn vốn đầu tư dự án xây dựng cầu Rạch Chiếc mới trên xa lộ Hà Nội kể từ ngày 1/6/2013.'
        actual = tokenize(text, format="text")
        expected = '( baodautu.vn ) Trao đổi với báo chí chiều 27/5 , ông Lê Quốc Bình , TGĐ Công ty cổ phần đầu tư hạ tầng kỹ thuật TP. HCM ( CII ) chính thức thông tin : UBND TP vừa có quyết định cho phép CII được thu phí hoàn vốn đầu tư dự án xây dựng cầu Rạch Chiếc mới trên xa lộ Hà Nội kể từ ngày 1/6/2013 .'
        self.assertEqual(expected, actual)

    def test_tokenize_tag(self):
        text = '(baodautu.vn) Trao đổi với báo chí chiều 27/5, ông Lê Quốc Bình, TGĐ Công ty cổ phần đầu tư hạ tầng kỹ thuật TP. HCM (CII) chính thức thông tin: UBND TP vừa có quyết định cho phép CII được thu phí hoàn vốn đầu tư dự án xây dựng cầu Rạch Chiếc mới trên xa lộ Hà Nội kể từ ngày 1/6/2013.'
        actual = tokenize(text, tag=True)
        expected = [('(', 'punct'),
                    ('baodautu.vn', 'url'),
                    (')', 'punct'),
                    ('Trao', 'word'),
                    ('đổi', 'word'),
                    ('với', 'word'),
                    ('báo', 'word'),
                    ('chí', 'word'),
                    ('chiều', 'word'),
                    ('27/5', 'datetime'),
                    (',', 'punct'),
                    ('ông', 'word'),
                    ('Lê', 'word'),
                    ('Quốc', 'word'),
                    ('Bình', 'word'),
                    (',', 'punct'),
                    ('TGĐ', 'word'),
                    ('Công', 'word'),
                    ('ty', 'word'),
                    ('cổ', 'word'),
                    ('phần', 'word'),
                    ('đầu', 'word'),
                    ('tư', 'word'),
                    ('hạ', 'word'),
                    ('tầng', 'word'),
                    ('kỹ', 'word'),
                    ('thuật', 'word'),
                    ('TP.', 'abbr'),
                    ('HCM', 'word'),
                    ('(', 'punct'),
                    ('CII', 'word'),
                    (')', 'punct'),
                    ('chính', 'word'),
                    ('thức', 'word'),
                    ('thông', 'word'),
                    ('tin', 'word'),
                    (':', 'sym'),
                    ('UBND', 'word'),
                    ('TP', 'word'),
                    ('vừa', 'word'),
                    ('có', 'word'),
                    ('quyết', 'word'),
                    ('định', 'word'),
                    ('cho', 'word'),
                    ('phép', 'word'),
                    ('CII', 'word'),
                    ('được', 'word'),
                    ('thu', 'word'),
                    ('phí', 'word'),
                    ('hoàn', 'word'),
                    ('vốn', 'word'),
                    ('đầu', 'word'),
                    ('tư', 'word'),
                    ('dự', 'word'),
                    ('án', 'word'),
                    ('xây', 'word'),
                    ('dựng', 'word'),
                    ('cầu', 'word'),
                    ('Rạch', 'word'),
                    ('Chiếc', 'word'),
                    ('mới', 'word'),
                    ('trên', 'word'),
                    ('xa', 'word'),
                    ('lộ', 'word'),
                    ('Hà', 'word'),
                    ('Nội', 'word'),
                    ('kể', 'word'),
                    ('từ', 'word'),
                    ('ngày', 'word'),
                    ('1/6/2013', 'datetime'),
                    ('.', 'punct')]
        self.assertEqual(expected, actual)



from underthesea.transformer.tagged import TaggedTransformer
from os.path import join, dirname
import pycrfsuite

template = [
    "T[-2].lower", "T[-1].lower", "T[0].lower", "T[1].lower", "T[2].lower",

    "T[-1].isdigit", "T[0].isdigit", "T[1].isdigit",

    "T[-1].istitle", "T[0].istitle", "T[1].istitle",
    "T[0,1].istitle", "T[0,2].istitle",

    "T[-2].is_in_dict", "T[-1].is_in_dict", "T[0].is_in_dict", "T[1].is_in_dict", "T[2].is_in_dict",
    "T[-2,-1].is_in_dict", "T[-1,0].is_in_dict", "T[0,1].is_in_dict", "T[1,2].is_in_dict",
    "T[-2,0].is_in_dict", "T[-1,1].is_in_dict", "T[0,2].is_in_dict",

    # word unigram and bigram and trigram
    "T[-2]", "T[-1]", "T[0]", "T[1]", "T[2]",
    "T[-2,-1]", "T[-1,0]", "T[0,1]", "T[1,2]",
    "T[-2,0]", "T[-1,1]", "T[0,2]",
]

transformer = TaggedTransformer(template)


class CRFModel:
    objects = {}

    def __init__(self, model_path=None):
        if not model_path:
            model_path = join(dirname(__file__), "wt_crf_2018_09_13.bin")
        estimator = pycrfsuite.Tagger()
        estimator.open(model_path)
        self.estimator = estimator

    @classmethod
    def instance(cls, model_path=None):
        if model_path not in cls.objects:
            cls.objects[model_path] = cls(model_path)
        object = cls.objects[model_path]
        return object

    def predict(self, sentence, format=None):
        tokens = [(token, "X") for token in sentence]
        x = transformer.transform([tokens])[0]
        tags = self.estimator.tag(x)
        return list(zip(sentence, tags))



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea import sent_tokenize


class TestSentTokenize(TestCase):
    def test_simple_1(self):
        text = ""
        actual = sent_tokenize(text)
        expected = []
        self.assertEqual(actual, expected)

    def test_simple_2(self):
        text = "hôm nay"
        actual = sent_tokenize(text)
        expected = [
            "hôm nay"
        ]
        self.assertEqual(actual, expected)

    def test_1(self):
        text = "Taylor cho biết lúc đầu cô cảm thấy ngại với cô bạn thân Amanda nhưng rồi mọi thứ trôi qua nhanh chóng. Amanda cũng thoải mái với mối quan hệ này."
        actual = sent_tokenize(text)
        expected = [
            "Taylor cho biết lúc đầu cô cảm thấy ngại với cô bạn thân Amanda nhưng rồi mọi thứ trôi qua nhanh chóng.",
            "Amanda cũng thoải mái với mối quan hệ này."
        ]
        self.assertEqual(actual, expected)



REPO = {
    "TC_GENERAL": {
        "cache_dir": "models",
        "type": "Classification",
        "license": "Open",
        "year": "2019",
        "model_path": "TC_GENERAL"
    },
    "TC_BANK": {
        "cache_dir": "models",
        "type": "Classification",
        "license": "Open",
        "year": "2019",
        "model_path": "TC_BANK"
    },
    "SA_GENERAL": {
        "cache_dir": "models",
        "type": "Sentiment",
        "license": "Open",
        "year": "2019",
        "model_path": "SA_GENERAL"
    },
    "SA_BANK": {
        "cache_dir": "models",
        "type": "Sentiment",
        "license": "Open",
        "year": "2019",
        "model_path": "SA_BANK"
    },
}



# -*- coding: utf-8 -*-

from unittest import TestCase
from underthesea.feature_engineering.text import Text, is_unicode


class TestText(TestCase):
    def test_text_1(self):
        input = u"đi học"
        output = Text(input)
        self.assertTrue(is_unicode(output))

    def test_text_2(self):
        input = "đi học"
        output = Text(input)
        self.assertTrue(is_unicode(output))

    def test_text_3(self):
        # string in unicode tổ hợp
        input = u"cộng hòa xã hội"
        output = Text(input)
        self.assertTrue(is_unicode(output))

    def test_text_4(self):
        # string in byte
        input = u"đi học".encode("utf-8")
        output = Text(input)
        self.assertTrue(is_unicode(output))



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea.sentiment import sentiment


class TestSentiment(TestCase):
    def test_no_text(self):
        text = ""
        actual = sentiment(text)
        expected = None
        self.assertEqual(actual, expected)

    def test_one_label_1(self):
        text = "Xem lại vẫn thấy xúc động và tự hào về BIDV của mình!"
        actual = [str(label) for label in sentiment(text, domain="bank")]
        expected = ['TRADEMARK#positive']
        self.assertEqual(actual, expected)

    def test_one_label_2(self):
        text = "Đky qua đường link ở bài viết này từ thứ 6 mà giờ chưa thấy ai lhe hết"
        actual = [str(label) for label in sentiment(text, domain="bank")]
        expected = ['CUSTOMER_SUPPORT#negative']
        self.assertEqual(actual, expected)

    def test_multi_label_1(self):
        text = "Dkm t chuyển vẫn bị mất phí"
        actual = [str(label) for label in sentiment(text, domain="bank")]
        expected = ['INTEREST_RATE#negative', 'MONEY_TRANSFER#negative']
        self.assertEqual(sorted(actual), sorted(expected))

    def test_multi_label_2(self):
        text = '''TUI cũng bó tay với BIDV Cần Thơ.
                Cả quận NK mà chỉ được lèo tèo mấy thùng ATM và luôn trong tình trạng nhìn thấy chữ Sorry cũng nh.ư hết tiền.
                Chán ko buồn nói. Qd có khác '''
        actual = [str(label) for label in sentiment(text, domain="bank")]
        expected = ['CARD#negative', 'CUSTOMER_SUPPORT#negative']
        self.assertEqual(sorted(actual), sorted(expected))

    def test_none_label(self):
        text = 'Có làm thẻ ngân hàng BIDV miễn phí ko'
        actual = sentiment(text, domain="bank")
        expected = None
        self.assertEqual(expected, actual)



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea.sentiment import sentiment


class TestSentiment(TestCase):
    def test_no_text(self):
        text = ""
        actual = sentiment(text)
        expected = None
        self.assertEqual(actual, expected)

    def test_1(self):
        text = "hàng kém chất lg,chăn đắp lên dính lông lá khắp người. thất vọng"
        actual = sentiment(text, domain="general")
        expected = "negative"
        self.assertEqual(actual, expected)

    def test_2(self):
        text = "Sản phẩm hơi nhỏ so với tưởng tượng nhưng chất lượng tốt, đóng gói cẩn thận."
        actual = sentiment(text, domain="general")
        expected = "positive"
        self.assertEqual(actual, expected)



# -*- coding: utf-8 -*-


def classify(X, domain=None):
    """
    Text classification

    Parameters
    ==========

    X: {unicode, str}
        raw sentence
    domain: {None, 'bank'}
        domain of text
            * None: general domain
            * bank: bank domain
    Returns
    =======
    tokens: list
        categories of sentence

    """
    if X == "":
        return None
    if domain == 'bank':
        from underthesea.classification import bank
        return bank.classify(X)
    from underthesea.classification import vntc
    return vntc.classify(X)



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea import ner


class TestNER(TestCase):
    def test_simple_cases(self):
        sentence = u""
        actual = ner(sentence)
        expected = []
        self.assertEqual(actual, expected)

    def test_accuracy(self):
        output = ner(u"Bộ Công Thương xóa một tổng cục, giảm nhiều đầu mối")
        self.assertEqual(output[0][3], "B-ORG")
        self.assertEqual(output[1][3], "I-ORG")



REPO = {
    "AIVIVN2019-SA": {
        "cache_dir": "datasets/AIVIVN2019-SA",
        "type": "Categorized",
        "license": "Close",
        "year": "2019",
        "filepath": "",
        "url_filename": "AIVIVN2019_SA.zip?dl=1"
    },
    "VLSP2018-NER": {
        "cache_dir": "datasets/VLSP2018-NER",
        "type": "Tagged",
        "license": "Close",
        "year": "2018",
        "filepath": "",
        "url_filename": "VLSP2018-NER.zip?dl=1"
    },
    "VLSP2018-SA": {
        "cache_dir": "datasets/VLSP2018-SA",
        "type": "Categorized",
        "license": "Close",
        "year": "2018",
        "filepath": "",
        "url_filename": "VLSP2018_SA.zip?dl=1"
    },
    "VTB-CHUNK": {
        "cache_dir": "datasets/VTB-CHUNK",
        "type": "Tagged",
        "license": "Close",
        "year": "2017",
        "filepath": "",
        "url_filename": "VTB-CHUNK.zip?dl=1"
    },
    "UTS2017-BANK": {
        "cache_dir": "datasets/UTS2017-BANK",
        "type": "Categorized",
        "license": "Open",
        "year": "2017",
        "filepath": "",
        "url": "https://www.dropbox.com/s/xl8sof2i1c35n62/UTS2017_BANK.zip?dl=1",
        "url_filename": "UTS2017_BANK.zip?dl=1"
    },
    "VLSP2016-NER": {
        "cache_dir": "datasets/VLSP2016-NER",
        "type": "Tagged",
        "license": "Close",
        "year": "2016",
        "filepath": "",
        "url_filename": "VLSP2016-NER.zip?dl=1"
    },
    "VLSP2016-SA": {
        "cache_dir": "datasets/VLSP2016-SA",
        "type": "Categorized",
        "license": "Close",
        "year": "2016",
        "filepath": "",
        "url_filename": "VLSP2016_SA.zip?dl=1"
    },
    "VLSP2013-WTK": {
        "cache_dir": "datasets/VLSP2013-WTK",
        "type": "Tagged",
        "license": "Close",
        "year": "2013",
        "filepath": "",
        "url_filename": "VLSP2013-WTK.zip?dl=1"
    },
    "VLSP2013-POS": {
        "cache_dir": "datasets/VLSP2013-POS",
        "type": "Tagged",
        "license": "Close",
        "year": "2013",
        "filepath": "",
        "url_filename": "VLSP2013-POS.zip?dl=1"
    },
    "VNESES": {
        "cache_dir": "datasets/LTA",
        "type": "Plaintext",
        "license": "Open",
        "year": "2012",
        "filepath": "VNESEScorpus.txt",
        "url": "https://www.dropbox.com/s/ci2kktkhhq46cnh/VNESEcorpus.txt?dl=1",
        "url_filename": "VNESEcorpus.txt?dl=1"
    },
    "VNTQ_BIG": {
        "cache_dir": "datasets/LTA",
        "type": "Plaintext",
        "license": "Open",
        "year": "2012",
        "filepath": "VNTQcorpus-big.txt",
        "url": "https://www.dropbox.com/s/on6naf4una3r5ot/VNTQcorpus-big.txt?dl=1",
        "url_filename": "VNTQcorpus-big.txt?dl=1"
    },
    "VNTQ_SMALL": {
        "cache_dir": "datasets/LTA",
        "type": "Plaintext",
        "license": "Open",
        "year": "2012",
        "filepath": "VNTQcorpus-small.txt",
        "url": "https://www.dropbox.com/s/04wjlnpwe4a94lq/VNTQcorpus-small.txt?dl=1",
        "url_filename": "VNTQcorpus-small.txt?dl=1"
    },
    "VNTC": {
        "cache_dir": "datasets/VNTC",
        "type": "Categorized",
        "license": "Open",
        "year": "2007",
        "filepath": "",
        "url": "https://www.dropbox.com/s/4iw3xtnkd74h3pj/VNTC.zip?dl=1",
        "url_filename": "VNTC.zip?dl=1"
    }
}



import logging
import os
import sys
from underthesea.data import Sentence
from underthesea.model_fetcher import ModelFetcher, UTSModel
from underthesea.models_lf.text_classifier import TextClassifier
from . import text_features

FORMAT = '%(message)s'
logging.basicConfig(format=FORMAT)
logger = logging.getLogger('underthesea')

sys.modules['text_features'] = text_features
model_path = ModelFetcher.get_model_path(UTSModel.sa_general)
classifier = None


def sentiment(text):
    global classifier
    if not classifier:
        if os.path.exists(model_path):
            classifier = TextClassifier.load(model_path)
        else:
            logger.error(
                f"Could not load model at {model_path}.\n"
                f"Download model with \"underthesea download {UTSModel.sa_general.value}\".")
            sys.exit(1)
    sentence = Sentence(text)
    classifier.predict(sentence)
    label = sentence.labels[0]
    if label == "1":
        label = "negative"
    if label == "0":
        label = "positive"
    return label



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import io
import os
from setuptools import setup

# Use the VERSION file to get version
version_file = os.path.join(os.path.dirname(__file__), 'underthesea', 'VERSION')
with open(version_file) as fh:
    version = fh.read().strip()

with io.open('README.rst', encoding="utf-8") as readme_file:
    readme = readme_file.read()

with io.open('HISTORY.rst') as history_file:
    history = history_file.read()

install_requires = [
    'Click>=6.0',
    'python-crfsuite>=0.9.6',
    'nltk',
    'tabulate',
    'tqdm',
    'requests',
    'joblib',
    'scikit-learn>=0.20,<0.22',
    'unidecode'
]

tests_require = [
    'nose==1.3.7'
]

setup_requires = [
]

setup(
    name='underthesea',
    version=version,
    description="Vietnamese NLP Toolkit",
    long_description=readme + '\n\n' + history,
    author="Vu Anh",
    author_email='anhv.ict91@gmail.com',
    url='https://github.com/undertheseanlp/underthesea',
    packages=[
        'underthesea',
    ],
    package_dir={'underthesea': 'underthesea'},
    entry_points={
        'console_scripts': [
            'underthesea=underthesea.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=install_requires,
    license="GNU General Public License v3",
    zip_safe=False,
    keywords='underthesea',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=tests_require,
    setup_requires=setup_requires
)



# -*- coding: utf-8 -*-
from underthesea import word_tokenize
from .model_crf import CRFPOSTagPredictor


def pos_tag(sentence, format=None):
    """
    Vietnamese POS tagging

    Parameters
    ==========

    sentence: {unicode, str}
        Raw sentence

    Returns
    =======
    tokens: list of tuple with word, pos tag
        tagged sentence
    Examples
    --------
    >>> # -*- coding: utf-8 -*-
    >>> from underthesea import pos_tag
    >>> sentence = "Chợ thịt chó nổi tiếng ở TPHCM bị truy quét"
    >>> pos_tag(sentence)
    [('Chợ', 'N'),
    ('thịt', 'N'),
    ('chó', 'N'),
    ('nổi tiếng', 'A'),
    ('ở', 'E'),
    ('TPHCM', 'Np'),
    ('bị', 'V'),
    ('truy quét', 'V')]
    """
    sentence = word_tokenize(sentence)
    crf_model = CRFPOSTagPredictor.Instance()
    result = crf_model.predict(sentence, format)
    return result



# -*- coding: utf-8 -*-
from click.testing import CliRunner
from unittest import TestCase
from underthesea.cli import download_model


class TestCliModel(TestCase):
    def test_download(self):
        runner = CliRunner()
        result = runner.invoke(download_model, ['SA_GENERAL'])
        print(result.output)



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea import classify


class TestClassify(TestCase):
    def test_classify_null_cases(self):
        sentence = u""
        actual = classify(sentence)
        expected = None
        self.assertEqual(actual, expected)

    def test_classify_simple_case(self):
        text = u"HLV ngoại đòi gần tỷ mỗi tháng dẫn dắt tuyển Việt Nam"
        actual = classify(text)[0]
        expected = "the_thao"
        self.assertEqual(actual, expected)



# -*- coding: utf-8 -*-
from unittest import TestCase
from underthesea import classify


class TestClassify(TestCase):
    def test_classify_simple_case(self):
        text = u"Mở tài khoản ATM thì có đc quà ko ad"
        actual = classify(text, domain='bank')
        expected = ["CUSTOMER_SUPPORT"]
        self.assertEqual(actual, expected)

    def test_classify_simple_case_2(self):
        text = u"Dkm t chuyển vẫn bị mất phí"
        actual = classify(text, domain='bank')
        expected = ['INTEREST_RATE', 'MONEY_TRANSFER']
        self.assertEqual(actual, expected)

    def test_classify_simple_case_3(self):
        text = u"Lãi suất từ BIDV rất ưu đãi"
        actual = classify(text, domain='bank')
        expected = ['INTEREST_RATE']
        self.assertEqual(actual, expected)
